diff --git a/src/backend/tcop/fastpath.c b/src/backend/tcop/fastpath.c
index 554ea576dd2a7ac8b51276c02a78d6c129ff4d8d..53b3a09ba2731efdfbe03e195a520434df67c277 100644
--- a/src/backend/tcop/fastpath.c
+++ b/src/backend/tcop/fastpath.c
@@ -8,7 +8,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/tcop/fastpath.c,v 1.56 2003/01/07 22:32:10 tgl Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/tcop/fastpath.c,v 1.57 2003/01/09 18:00:23 tgl Exp $
  *
  * NOTES
  *	  This cruft is the server side of PQfn.
@@ -64,6 +64,7 @@
 #include "catalog/pg_proc.h"
 #include "libpq/libpq.h"
 #include "libpq/pqformat.h"
+#include "miscadmin.h"
 #include "tcop/fastpath.h"
 #include "utils/acl.h"
 #include "utils/lsyscache.h"
diff --git a/src/include/catalog/pg_conversion.h b/src/include/catalog/pg_conversion.h
index 63dd6101bfe65ff656c1363f76cc7936e904be5e..c3d150368fe9ea0f242cfbfbb87896a859a9e9bc 100644
--- a/src/include/catalog/pg_conversion.h
+++ b/src/include/catalog/pg_conversion.h
@@ -8,7 +8,7 @@
  * Portions Copyright (c) 1996-2002, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
- * $Id: pg_conversion.h,v 1.8 2002/12/04 05:18:35 momjian Exp $
+ * $Id: pg_conversion.h,v 1.9 2003/01/09 18:00:24 tgl Exp $
  *
  * NOTES
  *	  the genbki.sh script reads this file and generates .bki
@@ -19,8 +19,6 @@
 #ifndef PG_CONVERSION_H
 #define PG_CONVERSION_H
 
-#include "miscadmin.h"
-
 /* ----------------
  *		postgres.h contains the system type definitions and the
  *		CATALOG(), BOOTSTRAP and DATA() sugar words so this file
diff --git a/src/include/commands/typecmds.h b/src/include/commands/typecmds.h
index 8f21aef7f4160ab8b80092a095c4ecf40130a127..fde284efeaf8a199187769d697573914d1b83aaf 100644
--- a/src/include/commands/typecmds.h
+++ b/src/include/commands/typecmds.h
@@ -7,14 +7,13 @@
  * Portions Copyright (c) 1996-2002, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
- * $Id: typecmds.h,v 1.3 2003/01/06 00:31:44 tgl Exp $
+ * $Id: typecmds.h,v 1.4 2003/01/09 18:00:24 tgl Exp $
  *
  *-------------------------------------------------------------------------
  */
 #ifndef TYPECMDS_H
 #define TYPECMDS_H
 
-#include "miscadmin.h"
 #include "nodes/parsenodes.h"
 
 
diff --git a/src/include/miscadmin.h b/src/include/miscadmin.h
index ce254a9261c96037e06e623d6b56399c99d01617..f5146926681afe94c708702229b6f82811d1c94b 100644
--- a/src/include/miscadmin.h
+++ b/src/include/miscadmin.h
@@ -12,7 +12,7 @@
  * Portions Copyright (c) 1996-2002, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
- * $Id: miscadmin.h,v 1.114 2002/12/09 18:21:43 tgl Exp $
+ * $Id: miscadmin.h,v 1.115 2003/01/09 18:00:24 tgl Exp $
  *
  * NOTES
  *	  some of the information in this file should be moved to
@@ -176,7 +176,7 @@ extern bool EnableSSL;
 extern bool SilentMode;
 extern int	MaxBackends;
 extern int	ReservedBackends;
-extern int	NBuffers;
+extern DLLIMPORT int	NBuffers;
 extern int	PostPortNumber;
 extern int	Unix_socket_permissions;
 extern char *Unix_socket_group;
@@ -200,13 +200,7 @@ extern char *ExpandDatabasePath(const char *path);
 extern void SetDatabaseName(const char *name);
 extern void SetDatabasePath(const char *path);
 
-/*
- * AclId		system identifier for the user, group, etc.
- */
-typedef int32 AclId;
-
 extern char *GetUserNameFromId(AclId userid);
-
 extern AclId GetUserId(void);
 extern void SetUserId(AclId userid);
 extern AclId GetSessionUserId(void);
diff --git a/src/include/pgstat.h b/src/include/pgstat.h
index 59e6a29f2b11e687b0743b282ac8332d2cb1cc07..6dcdcb1ecb53272d1210a0a9f963692745760abc 100644
--- a/src/include/pgstat.h
+++ b/src/include/pgstat.h
@@ -5,14 +5,12 @@
  *
  *	Copyright (c) 2001, PostgreSQL Global Development Group
  *
- *	$Id: pgstat.h,v 1.11 2002/12/05 04:04:51 momjian Exp $
+ *	$Id: pgstat.h,v 1.12 2003/01/09 18:00:24 tgl Exp $
  * ----------
  */
 #ifndef PGSTAT_H
 #define PGSTAT_H
 
-#include "miscadmin.h"
-
 /* ----------
  * Paths for the statistics files. The %s is replaced with the
  * installations $PGDATA.
diff --git a/src/include/utils/acl.h b/src/include/utils/acl.h
index 60765fc68ef1950985ab2edb3ee3be3323abc8dd..ac86a86855d0bffc84ea7fa5e83800e45de8756f 100644
--- a/src/include/utils/acl.h
+++ b/src/include/utils/acl.h
@@ -7,7 +7,7 @@
  * Portions Copyright (c) 1996-2002, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
- * $Id: acl.h,v 1.49 2002/12/05 04:04:51 momjian Exp $
+ * $Id: acl.h,v 1.50 2003/01/09 18:00:24 tgl Exp $
  *
  * NOTES
  *	  For backward-compatibility purposes we have to allow there
@@ -22,11 +22,12 @@
 #ifndef ACL_H
 #define ACL_H
 
-#include "miscadmin.h"
 #include "nodes/parsenodes.h"
 #include "utils/array.h"
 
 
+/* typedef AclId is declared in c.h */
+
 #define ACL_ID_WORLD	0		/* placeholder for id in a WORLD acl item */
 
 /*
diff --git a/src/include/c.h b/src/include/c.h
index 040a211a8f15fe4a2449888de47ff626226a1d1d..724bbb50b84a6cf6517e0a6cfab2a6542b077b4b 100644
--- a/src/include/c.h
+++ b/src/include/c.h
@@ -12,7 +12,7 @@
  * Portions Copyright (c) 1996-2002, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
- * $Id: c.h,v 1.134 2002/12/16 16:22:46 tgl Exp $
+ * $Id: c.h,v 1.135 2003/01/09 18:00:24 tgl Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -358,7 +358,7 @@ typedef float float4;
 typedef double float8;
 
 /*
  * Oid, RegProcedure, TransactionId, CommandId
  */
 
 /* typedef Oid is in postgres_ext.h */
@@ -376,6 +376,8 @@ typedef uint32 CommandId;
 
 #define FirstCommandId	((CommandId) 0)
 
+typedef int32 AclId;			/* user and group identifiers */
+
 /*
  * Array indexing support
  */
@@ -358,7 +358,7 @@ typedef float float4;
 
 /*
- * Oid, RegProcedure, TransactionId, CommandId
+ * Oid, RegProcedure, TransactionId, CommandId, AclId
  */
 